from amIFat.macros import *
from amIFat.calories import *
from amIFat.howfat import *
from amIFat.fat_problems import *

def main():
    #howfat
    print("Module: howfat")
    print('Testing howfat(age, height, weight, scale) with age=25, height=72, weigh=190, scale="i" ')
    print('Returning bmi score and obesity scale')
    print(howfat(25,72, 190, "i"))
    print("-------------------------------------------------------------------------------------------------------")

    #calories
    print("Module: calories")
    print('\nTesting calories(age, gender, height, weight, activityLevel, scale) with age=22, gender= "f", height=63, weigh=120, activityLevel=2, scale="i" ')
    print('Returning daily calorie intake (Active Metabolic Rate)')
    print(calories(22,"f",63,120,2,"i"))
    print("-------------------------------------------------------------------------------------------------------")
    
    #macros
    print("Module: macros")
    print("\nTesting calculateREE(age, gender, height, weight, scale) with age=21, gender='m', height=175, weight=80, scale='m' ")
    print('Returning resting energy expenditure ')
    ree=calculateREE(21, 'm', 175, 80, 'm')
    print(ree)
    
    print("\nTesting calculateTDEE(REE, userActivityLevel) with REE=" + str(ree) + ", userActivityLevel=4")
    print('Returning total daily energy expenditure')
    print(calculateTDEE(ree, 4))

    print("\nTesting weightLossOrGainCalculator(TDEE, lossOrGain) with TDEE=50, lossOrGain='g' ")
    print('Returning target TDEE for weight loss or gain')
    print(weightLossOrGainCalculator(50, 'g'))

    print("\nTesting macros(weight, targetTDEE, scale) with weight=36.2811791383, targetTDEE=3000000, scale='m'")
    print("Returning ideal macronutrient ratios for a given weight and TDEE")
    print(macros(36.2811791383, 3000000, 'm'))

    #fat_problems
    print("Module: fat_problems")
    print('\nTesting fat_problems(bmi) with bmi=32.0 ')
    print('Returning the diseases with risk levels')
    print(fat_problems(32.0))
    print("-------------------------------------------------------------------------------------------------------")    
   
main()



diseases_list = [
    '',
    'diabetes',                     #1
    'hypertension',                 #2
    'CVD',                          #3
    'heart disease',                #4
    'stroke',                       #5
    'gallbladder disease',          #6
    'osteoarthritis',               #7
    'sleep apnea',                  #8
    'breathing problems',           #9
    'cancer',                       #10
    'depression',                   #11
    'anxiety',                      #12
    'mental disorders',             #13
    'body pain',                    #14
    'flatty lever diseases',        #15
    'metabolic syndrome',           #16
    'eye diseases',                 #17
    'kidney diseases',              #18
    'malnutrition',                 #19
    'osteoporosis',                 #20
    'decreased muscle strength',    #21
    'hypothermia' ,                 #22
    'lowered immunity'              #23
]

levels_list = [
    '',
    'low',              #1
    'medium',           #2
    'increased',        #3
    'high',             #4
    'very high',        #5
    'extremely high'    #6
]

def fat_problems(bmi):

    #validate number
    if not isinstance(bmi, float):
        raise Exception('Please make sure bmi is of type float')
        return
    
    if bmi < 10.0 or 50.0 < bmi:
        raise Exception('Please make sure bmi is in the range of 10.0 and 50.0 inclusive')
        return


    # data structures initialisation
    diseasesWithRiskLevel = {}
    diseases = []
    risk_levels = []

    # extreme underweight
    if bmi < 15.0:
        diseases = [11,12,13,16,19,20,21,22,23]
        risk_levels = [5,4,5,6,6,6,6,5,6]

    # underweight
    elif 15.0 <= bmi < 18.5:
        diseases = [11,12,13,16,19,20,21,22,23]
        risk_levels = [3,3,4,4,4,5,5,4,5]

    # normal weight
    elif 18.5 <= bmi < 25.0:
        diseases = [1,3,4,5,8,9,12,15,19,20,21,23]
        risk_levels = [1,2,1,2,1,1,1,1,1,1,2,2]
    
    # overweight
    elif 25.0 <= bmi < 30.0:
        diseases = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,21,23]
        risk_levels = [3,3,3,2,2,3,2,2,3,2,3,2,2,2,3,3,3,4,2,2]

    # obesity
    elif 35.0 <= bmi < 40.0:
        diseases = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,21,23]
        risk_levels = [4,5,3,3,5,4,3,5,4,4,5,4,4,3,4,4,4,5,4,3]
    
    # extreme obesity
    else:
        diseases = [1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,21,23]
        risk_levels = [6,5,6,6,5,4,5,5,4,6,5,6,4,6,5,4,4,6,4,3]

    for i in range(len(diseases)):
            diseasesWithRiskLevel[diseases_list[diseases[i]]] = levels_list[risk_levels[i]] 

    return diseasesWithRiskLevel
